#include "title.h"
#include "horscreen.h"

title::title(QWidget *parent) : QWidget(parent)
{
    this->setFixedHeight(40);
    m_titleLayout = new QHBoxLayout(this);
    //左上角图标
    logoBtn = new QPushButton(this);
    logoBtn->setFixedSize(24, 24);
    logoBtn->setIcon(QIcon::fromTheme("kylin-weather", QIcon(":/res/contorl_icons/icon.png")));
    logoBtn->setIconSize(QSize(24, 24));
    logoBtn->setFocusPolicy(Qt::NoFocus);
    //左上角文字
    m_label = new QLabel(this);
    m_label->setText(tr("Weather"));
    m_label->setAlignment(Qt::AlignVCenter);
    QPalette palText = m_label->palette();
    palText.setColor(QPalette::WindowText, Qt::white);
    m_label->setPalette(palText);

    //窗口四联--菜单
    g_menu = new menuModule(this);
    g_menu->setFocusPolicy(Qt::NoFocus);
    g_menu->setAttribute(Qt::WA_TranslucentBackground);

    //窗口四联--最小化按钮
    btnMinimize = new QPushButton(this);
    btnMinimize->setFixedSize(QSize(32, 32));
    btnMinimize->setToolTip(tr("minimize"));
    btnMinimize->setFocusPolicy(Qt::NoFocus);                           //设置焦点类型
    btnMinimize->setIcon(QIcon::fromTheme("window-minimize-symbolic")); //主题库的最小化图标
    btnMinimize->setProperty("isWindowButton", 0x1);
    btnMinimize->setProperty("useIconHighlightEffect", 0x2);
    btnMinimize->setFlat(true);
    btnMinimize->setProperty("setIconHighlightEffectDefaultColor", QColor(Qt::white));
    //窗口四联--最大化/还原按钮
    //全屏按钮注释代码
    btnMaximum = new QPushButton(this);
    btnMaximum->setIcon(QIcon::fromTheme("window-maximize-symbolic"));
    btnMaximum->setFixedSize(QSize(32, 32));
    btnMaximum->setToolTip(tr("full screen"));
    btnMaximum->setFocusPolicy(Qt::NoFocus); //设置焦点类型
    btnMaximum->setProperty("isWindowButton", 0x1);
    btnMaximum->setProperty("useIconHighlightEffect", 0x2);
    btnMaximum->setProperty("setIconHighlightEffectDefaultColor", QColor(Qt::white));
    btnMaximum->setFlat(true);
    btnMaximum->hide();
    //窗口四联--关闭按钮
    btnCancel = new QPushButton(this);
    btnCancel->setToolTip(tr("close"));
    btnCancel->setIcon(QIcon::fromTheme("window-close-symbolic"));
    btnCancel->setFixedSize(QSize(32, 32));
    btnCancel->setFocusPolicy(Qt::NoFocus); //设置焦点类型
    btnCancel->setProperty("isWindowButton", 0x2);
    btnCancel->setProperty("useIconHighlightEffect", 0x8);
    btnCancel->setFlat(true);
    btnCancel->setProperty("setIconHighlightEffectDefaultColor", QColor(Qt::white));
    this->initConnection();
    this->initLayout();
    this->initQss();
}

void title::initConnection()
{
    connect(btnMinimize, &QPushButton::clicked, horscreen::mutual, &horscreen::showMinimized);
    //    connect(btnMaximum,&QPushButton::clicked,horscreen::mutual,&horscreen::showMaximized);
    connect(btnCancel, &QPushButton::clicked, horscreen::mutual, &horscreen::hide);
    //全屏按钮注释代码
    connect(btnMaximum, &QPushButton::clicked, this, &title::recovery);

    connect(g_menu, &menuModule::aboutShow, this, &title::aboutShow);

    // 首次允许定位弹窗点击“是”更改菜单内允许定位为“是”
    connect(this, &title::setMenuModuleAllowLocationYes, g_menu, &menuModule::setMenuModuleAllowLocationYes);
}

void title::initLayout()
{
    m_titleLayout->setMargin(0);
    m_titleLayout->setSpacing(0);
    m_titleLayout->addSpacing(12);
    m_titleLayout->addWidget(logoBtn);
    m_titleLayout->addSpacing(4);
    m_titleLayout->addWidget(m_label, 0, Qt::AlignVCenter);
    m_titleLayout->addStretch();
    m_titleLayout->addWidget(g_menu->menuButton);
    m_titleLayout->addSpacing(2);
    m_titleLayout->addWidget(btnMinimize);
    m_titleLayout->addSpacing(2);
    if (ViewVar::platFormList.contains(ViewVar::platForm)) {
        btnMaximum->show();
        //全屏按钮注释代码
        m_titleLayout->addWidget(btnMaximum);
        m_titleLayout->addSpacing(2);
    } else {
        btnMaximum->hide();
    }
    m_titleLayout->addWidget(btnCancel);
    m_titleLayout->addSpacing(4);
    this->setLayout(m_titleLayout);
}

void title::initQss()
{
    logoBtn->setStyleSheet("QPushButton{border:0px;border-radius:4px;background:transparent;}"
                           "QPushButton::hover{border:0px;border-radius:4px;background:transparent;}"
                           "QPushButton::pressed{border:0px;border-radius:4px;background:transparent;}");
}

// bool title::eventFilter(QObject *watched, QEvent *event)
//{
//    if(watched == this)
//    {
//        if (event->type() == QEvent::MouseButtonDblClick)           //判断类型
//        {
//            QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
//            if (mouseEvent->button() == Qt::LeftButton) //判断左键
//            {
//                Widget::mutual->slotShowMaximized();
//            }
//        }
//    }
//    return QWidget::eventFilter(watched,event);
//}
